@@ -1,26 +1,19 @@
-use 5.010;
-use strict;
+use v5.12;
 use warnings;
-use utf8;
 
-package Neo4j::Driver::Type::Duration;
+package Neo4j::Driver::Type::Duration 1.02;
 # ABSTRACT: Represents a Neo4j temporal duration value
-$Neo4j::Driver::Type::Duration::VERSION = '0.52';
+
 
 # For documentation, see Neo4j::Driver::Types.
 
 
 use parent 'Neo4j::Types::Duration';
-use parent 'Neo4j::Driver::Type::Temporal';
 
 
 sub _parse {
 	my ($self) = @_;
 	
-	if ( ! exists $self->{T} ) {  # JSON format
-		$self->{T} = $self->{data};
-	}
-	
 	my ($minus, $years, $months, $weeks, $days, $hours, $mins, $secs, $nanos) = $self->{T} =~ m/^(-)?P(?:([-0-9.]+)Y)?(?:([-0-9.]+)M)?(?:([-0-9.]+)W)?(?:([-0-9.]+)D)?(?:T(?:([-0-9.]+)H)?(?:([-0-9.]+)M)?(?:([-0-9]+)(?:[,.]([0-9]+))?S)?)?$/;
 	
 	my $sign = $minus ? -1 : 1;
